# mig_meow

MEOW is a Manager for Event Oriented Workflows.

It is designed to interact with the MiG 
(https://sourceforge.net/projects/migrid/) and provides methods for 
workflows to be defined and manipulated within jupyter notebooks.

